package io.github.gretzky.volume

import android.content.BroadcastReceiver
import android.content.Context
import android.content.Intent
import android.content.IntentFilter

import com.facebook.react.bridge.ReactApplicationContext

class RNDUVolumeBroadcastReceiver(reactContext: ReactApplicationContext) : RNDUVolumeReceiver(reactContext) {

    private val mVolumeBroadcastReceiver : VolumeBroadcastReceiver

    init {
        mVolumeBroadcastReceiver = VolumeBroadcastReceiver()
    }

    override fun register() {
        val filter = IntentFilter()
        filter.addAction("android.media.VOLUME_CHANGED_ACTION")
        mReactContext.registerReceiver(mVolumeBroadcastReceiver, filter)
        mVolumeBroadcastReceiver.isRegistered = true
        updateAndSendVolume()
    }

    override fun unregister() {
        if (mVolumeBroadcastReceiver.isRegistered) {
            mReactContext.unregisterReceiver(mVolumeBroadcastReceiver)
            mVolumeBroadcastReceiver.isRegistered = false
        }
    }

    private fun updateAndSendVolume() {
        updateVolume(currentVolume)
    }

    private inner class VolumeBroadcastReceiver : BroadcastReceiver() {

        var isRegistered = false

        override fun onReceive(context: Context, intent: Intent) {
            val action = intent.getAction()
            if (action != null && action.equals("android.media.VOLUME_CHANGED_ACTION")) {
                updateAndSendVolume()
            }
        }
    }
}
