package io.github.gretzky.volume

import android.content.Context
import android.media.AudioManager

import com.facebook.react.bridge.Promise
import com.facebook.react.bridge.ReactApplicationContext
import com.facebook.react.bridge.ReactContextBaseJavaModule
import com.facebook.react.bridge.ReactMethod

import io.github.gretzky.volume.RNDUVolumeBroadcastReceiver
import io.github.gretzky.volume.RNDUVolumeReceiver

class RNDUVolumeModule(reactContext: ReactApplicationContext) : ReactContextBaseJavaModule(reactContext) {

    private val mVolumeReceiver: RNDUVolumeReceiver
    private val mAudioManager: AudioManager

    override fun getName(): String {
        return "RNDUVolume"
    }

    init {
        mVolumeReceiver = RNDUVolumeBroadcastReceiver(reactContext)
        mAudioManager = reactContext.getSystemService(Context.AUDIO_SERVICE) as AudioManager
    }

    override fun initialize() {
        mVolumeReceiver.register()
    }

    override fun onCatalystInstanceDestroy() {
        mVolumeReceiver.unregister()
    }

    @ReactMethod
    fun getCurrentState(promise: Promise) {
        promise.resolve(mVolumeReceiver.createEventMap())
    }

    @ReactMethod
    fun setVolume(volume: Int) {
        mAudioManager.setStreamVolume(AudioManager.STREAM_MUSIC, volume, 0)
        mVolumeReceiver.updateVolume(volume)
    }
}
