package io.github.gretzky.volume

import android.content.Context
import android.content.Intent
import android.content.IntentFilter
import android.media.AudioManager

import com.facebook.react.bridge.ReactApplicationContext
import com.facebook.react.bridge.WritableMap
import com.facebook.react.bridge.WritableNativeMap
import com.facebook.react.modules.core.DeviceEventManagerModule

abstract class RNDUVolumeReceiver(val reactContext: ReactApplicationContext) {

    val mReactContext: ReactApplicationContext
    val mAudioManager: AudioManager

    private var mCurrentVolume: Int = 0

    val currentVolume: Int
        get() = mAudioManager.getStreamVolume(AudioManager.STREAM_MUSIC)

    init {
        mReactContext = reactContext as ReactApplicationContext
        mAudioManager = reactContext.getSystemService(Context.AUDIO_SERVICE) as AudioManager

        mCurrentVolume = currentVolume
    }

    internal abstract fun register()

    internal abstract fun unregister()

    fun sendChangeEvent() {
        reactContext
            .getJSModule(DeviceEventManagerModule.RCTDeviceEventEmitter::class.java)
            .emit("volume", createEventMap())
    }

    fun updateVolume(volume: Int) {
        val volumeChanged = volume != mCurrentVolume

        if (volumeChanged) {
            mCurrentVolume = volume
            sendChangeEvent()
        }
    }

    fun createEventMap(): WritableMap {
        var event: WritableMap = WritableNativeMap()
        var details: WritableMap = WritableNativeMap()

        details.putInt("level", currentVolume)

        event.putMap("volume", details)

        return event
    }
}
