package io.github.gretzky.volume.delegate;

import android.app.Activity;
import android.content.Context;
import android.media.AudioManager;
import android.os.Bundle;
import android.view.KeyEvent;
import com.facebook.react.ReactActivityDelegate;
import javax.annotation.Nullable;

// this file is in java and not kotlin
// bc the `MainActivity` class that consumes this in an RN project
// can't pre-compile an imported kotlin class
// ¯\_(ツ)_/¯
public class VolumeDelegate extends ReactActivityDelegate {
    private Bundle mInitialProps = null;
    private final @Nullable Activity mActivity;
    private AudioManager mAudioManager;

    public VolumeDelegate(Activity activity, String mainComponentName) {
        super(activity, mainComponentName);
        this.mActivity = activity;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        mActivity.setVolumeControlStream(AudioManager.STREAM_MUSIC);
        mAudioManager = (AudioManager) mActivity.getSystemService(Context.AUDIO_SERVICE);

        mAudioManager.adjustStreamVolume(
                AudioManager.STREAM_NOTIFICATION, AudioManager.ADJUST_MUTE, 0);
        mAudioManager.adjustStreamVolume(AudioManager.STREAM_ALARM, AudioManager.ADJUST_MUTE, 0);
        mAudioManager.adjustStreamVolume(AudioManager.STREAM_RING, AudioManager.ADJUST_MUTE, 0);
        mAudioManager.adjustStreamVolume(AudioManager.STREAM_SYSTEM, AudioManager.ADJUST_MUTE, 0);
    }

    @Override
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if ((keyCode == KeyEvent.KEYCODE_VOLUME_DOWN)) {
            mAudioManager.adjustStreamVolume(
                    AudioManager.STREAM_MUSIC, AudioManager.ADJUST_LOWER, 0);
            return true;
        } else if ((keyCode == KeyEvent.KEYCODE_VOLUME_UP)) {
            mAudioManager.adjustStreamVolume(
                    AudioManager.STREAM_MUSIC, AudioManager.ADJUST_RAISE, 0);
            return true;
        } else {
            return super.onKeyDown(keyCode, event);
        }
    }
}
