import * as React from "react";
import Icon from "react-native-vector-icons/MaterialCommunityIcons";
import { VolumeComponentProps } from "../util/types";

const renderIcon = (name: string, color?: string) => <Icon size={20} color={color} name={name} />;

/**
 * VolumeIcon - renders an icon to display the volume level
 */
const VolumeIcon: React.FC<VolumeComponentProps> = ({ state, color }) => {
  const level = state.volume.level;
  const isMute = level === 0;

  const renderVolumeIcon = (level: string) => renderIcon(`volume-${level}`, color);

  if (isMute) {
    return renderIcon("volume-variant-off", "#ee4444"); // the variant-off icon looks more like 'mute', so we use it here
  }

  switch (Boolean(level)) {
    case level > 0 && level < 5:
      return renderVolumeIcon("low");
    case level >= 5 && level < 10:
      return renderVolumeIcon("medium");
    case level >= 10:
      return renderVolumeIcon("high");
    default:
      return renderVolumeIcon("mute"); // the `mute` icon looks more like an 'off' icon, so we use it here
  }
};

VolumeIcon.defaultProps = {
  color: "black"
};

export default VolumeIcon;
