import { NativeModules, NativeEventEmitter } from "react-native";
import Listener from "./listener";
import { VolumeModule, VolumeState, VolumeChangeHandler, VolumeSubscription } from "./types";

const VolumeNativeModule: VolumeModule = NativeModules.RNDUVolume;

if (!VolumeNativeModule) {
  throw new Error(`@react-native-device-utils/volume: Native Module is null. Steps to fix:

• Run \`react-native-link @react-native-device-utils/volume\` in the project root
• Rebuild and run the app
• Manually link the library if necessary
• If you're getting this error while testing, you didn't read the README. #shame

If none of these fix the issue, open an issue on Github: https://github.com/gretzky/react-native-device-utils`);
}

let nativeEventEmitter: NativeEventEmitter | null = null;

const VolumeInterface = {
  ...VolumeNativeModule,
  get eventEmitter(): NativeEventEmitter | null {
    if (!nativeEventEmitter) {
      /// @ts-ignore
      nativeEventEmitter = new NativeEventEmitter(VolumeNativeModule);
    }

    return nativeEventEmitter;
  },

  addEventListener(listener: VolumeChangeHandler): VolumeSubscription {
    Listener.add(listener);
    return (): void => {
      Listener.remove(listener);
    };
  },

  getCurrentState(): Promise<VolumeState> {
    return VolumeNativeModule.getCurrentState();
  },

  setVolume(amount: number): void {
    if (amount > 15) {
      throw new Error("Max volume amount is 15.");
    }
    return VolumeNativeModule.setVolume(amount);
  }
};

export default VolumeInterface;
