import { NativeEventSubscription } from "react-native";
import VolumeInterface from "./interface";
import { VolumeChangeHandler, VolumeState } from "./types";

const _subscriptions = new Set<VolumeChangeHandler>();
let _nativeEventSubscription: NativeEventSubscription | null = null;
let _latestState: VolumeState = null;

function _listenerHandler(state: VolumeState): void {
  _latestState = state;
  _subscriptions.forEach((handler): void => handler(state));
}

function add(handler: VolumeChangeHandler, latestOnListen: boolean = true): void {
  _subscriptions.add(handler);

  if (latestOnListen) {
    if (_latestState) {
      handler(_latestState);
    } else {
      VolumeInterface.getCurrentState().then((state: VolumeState): void => {
        _latestState = state;
        handler(_latestState);
      });
    }
  }

  if (_subscriptions.size > 0 && !_nativeEventSubscription) {
    /// @ts-ignore
    _nativeEventSubscription = VolumeInterface.eventEmitter.addListener("volume", _listenerHandler);
  }
}

function clear(): void {
  _subscriptions.clear();

  if (_nativeEventSubscription) {
    _nativeEventSubscription.remove();
    _nativeEventSubscription = null;
  }
}

function remove(handler: any): void {
  _subscriptions.delete(handler);

  if (_subscriptions.size === 0 && _nativeEventSubscription) {
    _nativeEventSubscription.remove();
    _nativeEventSubscription = null;
  }
}

export default {
  add,
  remove,
  clear
};
